import { IBrowserVersionedRegExp } from '../useragent';
export declare const DIGIT_PATTERN = "\\d";
export declare const NUMBER_PATTERN: string;
export declare const BRACED_NUMBER_PATTERN: string;
export declare const ESCAPE_SYMBOL = "\\";
/**
 * Join RegExp parts with "or".
 * @param  parts - Some RegExp parts.
 * @param  wrapRequired - Should always wrap with braces.
 * @return Joined parts.
 */
export declare function joinParts(parts: string[], wrapRequired?: boolean): string;
/**
 * Join RegExps with "or".
 * @param  versionedBrowsersRegExps - RegExps strings array.
 * @return Joined RegExps string.
 */
export declare function joinVersionedBrowsersRegExps(versionedBrowsersRegExps: IBrowserVersionedRegExp[]): string;
/**
 * Contains number pattern or not.
 * @param  regExp - Target string or RegExp.
 * @return Has or not.
 */
export declare function hasNumberPattern(regExp: string | RegExp): boolean;
/**
 * Find number patterns count.
 * @param regExp - Target string or RegExp.
 * @return Number patterns count.
 */
export declare function getNumberPatternsCount(regExp: string | RegExp): number;
/**
 * Convert RegExp to string without slashes.
 * @param  regExp - Target RegExp.
 * @return RegExp string without slashes.
 */
export declare function regExpToString(regExp: RegExp): string;
/**
 * Replace number patterns.
 * @param  regExp - Target RegExp.
 * @param  numbers - Number patterns to paste.
 * @param  numberPatternsCount - Number patterns count to replace.
 * @return RegExp string with replaced number patterns.
 */
export declare function replaceNumberPatterns(regExp: string | RegExp, numbers: string[], numberPatternsCount?: number): string;
/**
 * Transform number to digits array.
 * @param  num - Target number.
 * @return Digits array.
 */
export declare function numberToDigits(num: string | number): number[];
/**
 * Skip every char inside square braces.
 * @param  skip - Current skip state.
 * @param  prevChar - Previous char.
 * @param  char - Current char to check.
 * @return Should skip this char or not.
 */
export declare function skipSquareBraces(skip: boolean, prevChar: string, char: string): boolean;
/**
 * Get possible RegExp group postfix.
 * @param  regExpStr - Whole RegExp string.
 * @param  startFrom - Index to start capture.
 * @return RegExp group postfix part.
 */
export declare function capturePostfix(regExpStr: string, startFrom: number): string;
//# sourceMappingURL=util.d.ts.map