import { ISemverLike, ISemver, IRangedSemver, ISemverCompareOptions } from './types';
/**
 * Get semver from string or array.
 * @param  version - Target to convert.
 * @return Array with semver parts.
 */
export declare function semverify(version: ISemverLike): ISemver;
/**
 * Compare semvers.
 * @param  a - Semver to compare.
 * @param  b - Semver to compare with.
 * @param  options - Compare options.
 * @return Equals or not.
 */
export declare function compareSemvers([major, minor, patch]: ISemver, [majorBase, minorBase, patchBase]: ISemver, { ignoreMinor, ignorePatch, allowHigherVersions }: ISemverCompareOptions): boolean;
/**
 * Get required semver parts count.
 * @param  version - Semver parts or ranges.
 * @param  options - Semver compare options.
 * @return Required semver parts count.
 */
export declare function getRequiredSemverPartsCount(version: ISemver | IRangedSemver, { ignoreMinor, ignorePatch, allowZeroSubverions }: ISemverCompareOptions): number;
/**
 * Ranged semver to regexp patterns.
 * @param  rangedVersion - Ranged semver.
 * @param  options - Semver compare options.
 * @return Array of regexp pattern strings.
 */
export declare function rangedSemverToRegExp(rangedVersion: IRangedSemver, { ignoreMinor, ignorePatch, allowHigherVersions }: ISemverCompareOptions): string[][];
//# sourceMappingURL=semver.d.ts.map